"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BidirectionalMap = void 0;
class BidirectionalMap {
    constructor(entries = []) {
        this.keyToValue = new Map();
        this.valueToKey = new Map();
        for (const [key, value] of entries) {
            this.set(key, value);
        }
    }
    set(key, value) {
        if (this.keyToValue.has(key)) {
            const oldValue = this.keyToValue.get(key);
            this.valueToKey.delete(oldValue);
        }
        if (this.valueToKey.has(value)) {
            const oldKey = this.valueToKey.get(value);
            this.keyToValue.delete(oldKey);
        }
        this.keyToValue.set(key, value);
        this.valueToKey.set(value, key);
    }
    getByKey(key) {
        return this.keyToValue.get(key);
    }
    getByValue(value) {
        return this.valueToKey.get(value);
    }
    deleteByKey(key) {
        const value = this.keyToValue.get(key);
        if (value !== undefined) {
            this.keyToValue.delete(key);
            this.valueToKey.delete(value);
        }
    }
    deleteByValue(value) {
        const key = this.valueToKey.get(value);
        if (key !== undefined) {
            this.valueToKey.delete(value);
            this.keyToValue.delete(key);
        }
    }
    hasKey(key) {
        return this.keyToValue.has(key);
    }
    hasValue(value) {
        return this.valueToKey.has(value);
    }
    keys() {
        return this.valueToKey.values();
    }
    values() {
        return this.keyToValue.values();
    }
}
exports.BidirectionalMap = BidirectionalMap;
